#ifndef NT2_INCLUDE_CONSTANTS_INFINITES_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_INFINITES_HPP_INCLUDED

#include <nt2/constant/include/constants/infinites.hpp>

#endif
